@@ -11,8 +11,8 @@ from .exceptions import (
     HttpClientException, SessionException
 )
 from .models import (
-    ObjectRef, Position, ObjectType, Font, Color, Image, BoundingRect, Paragraph, FormFieldRef,
-    PositionMode, ShapeType, Point
+    ObjectRef, Position, ObjectType, Font, Color, Image, BoundingRect, Paragraph, FormFieldRef, TextObjectRef,
+    PositionMode, ShapeType, Point, StandardFonts
 )
 from .paragraph_builder import ParagraphBuilder
 
@@ -29,9 +29,11 @@ __all__ = [
     "BoundingRect",
     "Paragraph",
     "FormFieldRef",
+    "TextObjectRef",
     "PositionMode",
     "ShapeType",
     "Point",
+    "StandardFonts",
     "PdfDancerException",
     "FontNotFoundException",
     "ValidationException",
